# Generated by Django 4.1 on 2023-04-03 10:50

import perma.blocks
import perma.model_fields
import tour_guide.model_fields
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_auxiliaries.servable
import django_auxiliaries.variable_scope
import modelcluster.contrib.taggit
import modelcluster.fields
import uuid
import wagtail.contrib.routable_page.models
import wagtail.models
import wagtail_block_model_field.fields
import wagtail_preference_blocks.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('wagtailcore', '0078_referenceindex'),
        ('wagtail_synopsis', '0001_initial'),
        ('officekit', '0002_add_address_formats'),
    ]

    operations = [
        migrations.CreateModel(
            name='Record',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('translation_key', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('has_unpublished_changes', models.BooleanField(default=False, editable=False, verbose_name='has unpublished changes')),
                ('first_published_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='first published at')),
                ('last_published_at', models.DateTimeField(editable=False, null=True, verbose_name='last published at')),
                ('go_live_at', models.DateTimeField(blank=True, null=True, verbose_name='go live date/time')),
                ('expire_at', models.DateTimeField(blank=True, null=True, verbose_name='expiry date/time')),
                ('expired', models.BooleanField(default=False, editable=False, verbose_name='expired')),
                ('key', models.CharField(max_length=7, validators=[django.core.validators.RegexValidator('^[BCDFGHJKLMNPRSTVWXYZ0123456789]{7}$', code='invalid_identifier', message='A valid identifier consists of six letters or digits from the set B C D F G H J K L M N P R S T V W X Y Z 0 1 2 3 4 5 6 7 8 9.')])),
                ('live', models.BooleanField(default=False, verbose_name='live')),
                ('description', perma.model_fields.RecordDescriptionField(blank=True, default='[]', help_text='A description of the contents of this record.')),
                ('title', models.CharField(help_text="The record title as you'd like it to be seen by the public", max_length=255, verbose_name='title')),
                ('seo_title', models.CharField(blank=True, help_text='The name of the page displayed on search engine results as the clickable headline.', max_length=255, verbose_name='title tag')),
                ('search_description', models.TextField(blank=True, help_text='The descriptive text displayed underneath a headline in search engine results.', verbose_name='meta description')),
                ('preferences_context', wagtail_block_model_field.fields.BlockModelField(wagtail_preference_blocks.blocks.PreferencesContextBlock(label='Preferences Context'), wagtail_preference_blocks.blocks.PreferencesContext, verbose_name='Preferences')),
                ('created_by_user', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='created by user')),
                ('latest_revision', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.revision', verbose_name='latest revision')),
                ('live_revision', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.revision', verbose_name='live revision')),
                ('locale', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='wagtailcore.locale')),
            ],
            bases=(django_auxiliaries.variable_scope.WagtailPageMixin, models.Model, wagtail.models.PreviewableMixin, django_auxiliaries.servable.Servable),
        ),
        migrations.CreateModel(
            name='RecordIndexPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.page')),
                ('navigation_categories', tour_guide.model_fields.NavigationCategoriesField(blank=True, choices_function_name='tour_guide.categories.navigation_category_choices', max_length=128, verbose_name='Navigation Categories')),
            ],
            options={
                'verbose_name': 'Record Index Page',
                'verbose_name_plural': 'Record Index Pages',
            },
            bases=(wagtail.contrib.routable_page.models.RoutablePageMixin, 'wagtailcore.page', models.Model),
        ),
        migrations.CreateModel(
            name='RecordTag',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='name')),
                ('slug', models.SlugField(allow_unicode=True, max_length=100, unique=True, verbose_name='slug')),
            ],
            options={
                'verbose_name': 'record tag',
                'verbose_name_plural': 'record tags',
            },
        ),
        migrations.CreateModel(
            name='RecordTagItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_object', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_items', to='perma.record')),
                ('tag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_record', to='perma.recordtag')),
            ],
            options={
                'unique_together': {('content_object', 'tag')},
            },
        ),
        migrations.CreateModel(
            name='RecordSynopsis',
            fields=[
                ('synopsis_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtail_synopsis.synopsis')),
                ('model', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='synopsis', to='perma.record')),
            ],
            options={
                'ordering': ['sort_order'],
                'abstract': False,
            },
            bases=('wagtail_synopsis.synopsis',),
        ),
        migrations.AddField(
            model_name='record',
            name='tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(blank=True, help_text='A comma-separated list of tags.', through='perma.RecordTagItem', to='perma.RecordTag', verbose_name='Tags'),
        ),
        migrations.CreateModel(
            name='PermaSiteSettings',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('canonical_record_index_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='perma.recordindexpage')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.site')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RecordResource',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('identifier', models.CharField(default='', max_length=128, validators=[django.core.validators.RegexValidator('^[A-Za-z_][A-Za-z_0-9]*$', code='invalid_identifier', message='A valid identifier starts with an alphanumeric letter or underscore and contains only alphanumeric letters, underscores or digits.')])),
                ('definition', wagtail_block_model_field.fields.BlockModelField(perma.blocks.ResourceBlock(), perma.blocks.ResourceBlockValue)),
                ('record', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='resources', to='perma.record')),
            ],
            options={
                'verbose_name': 'Record Resource',
                'verbose_name_plural': 'Record Resource',
                'ordering': ['sort_order'],
                'abstract': False,
                'unique_together': {('record', 'identifier')},
            },
        ),
        migrations.CreateModel(
            name='RecordRequirement',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('identifier', models.CharField(default='', max_length=128, validators=[django.core.validators.RegexValidator('^[A-Za-z_][A-Za-z_0-9]*$', code='invalid_identifier', message='A valid identifier starts with an alphanumeric letter or underscore and contains only alphanumeric letters, underscores or digits.')])),
                ('definition', wagtail_block_model_field.fields.BlockModelField(perma.blocks.RequirementBlock(), perma.blocks.RequirementBlockValue)),
                ('record', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='requirements', to='perma.record')),
            ],
            options={
                'verbose_name': 'Requirement in Record',
                'verbose_name_plural': 'Requirement in Record',
                'ordering': ['sort_order'],
                'abstract': False,
                'unique_together': {('record', 'identifier')},
            },
        ),
        migrations.CreateModel(
            name='RecordAuthor',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='records', to='officekit.groupmember')),
                ('record', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='authors', to='perma.record')),
            ],
            options={
                'verbose_name': 'Author in Record',
                'verbose_name_plural': 'Authors in Record',
                'ordering': ['sort_order'],
                'abstract': False,
                'unique_together': {('author', 'record')},
            },
        ),
        migrations.AlterUniqueTogether(
            name='record',
            unique_together={('key', 'locale'), ('translation_key', 'locale')},
        ),
    ]
